@@ -1,7 +1,6 @@
 import unittest
 
 import ddt
-import pytest
 
 from iker.common.utils.sequtils import batch_yield
 from iker.common.utils.sequtils import chunk, chunk_between, chunk_with_key, merge_chunks
@@ -813,7 +812,7 @@ class SeqTest(unittest.TestCase):
         self.assertEqual(seq(data).data, expect)
 
     def test_builtin_init__unsupported_data_type(self):
-        with pytest.raises(ValueError):
+        with self.assertRaises(ValueError):
             seq(object())
 
     @ddt.data(
@@ -844,7 +843,7 @@ class SeqTest(unittest.TestCase):
         self.assertEqual(actual.data, expect)
 
     def test_builtin_getitem__unsupported_index_type(self):
-        with pytest.raises(ValueError):
+        with self.assertRaises(ValueError):
             seq([])[object()]
 
     @ddt.data(
