@@ -5,7 +5,6 @@ from dataclasses import dataclass
 from decimal import Decimal
 
 import ddt
-import pytest
 
 from iker.common.utils.testutils import nested_approx, return_callee, throw_callee
 
@@ -403,5 +402,5 @@ class TestUtilsTest(unittest.TestCase):
     def test_throw_callee(self):
         callee = throw_callee(ValueError)
 
-        with pytest.raises(ValueError):
+        with self.assertRaises(ValueError):
             callee(object())
